@@ -38,10 +38,8 @@ est_g_exp <- function(A,
                       fit_type = c("hal", "sl"),
                       sl_learners_density = NULL,
                       haldensify_args = list(
-                        n_bins = c(5, 10),
-                        grid_type = c("equal_range", "equal_mass"),
-                        lambda_seq = exp(seq(-1, -13, length = 300)),
-                        use_future = FALSE
+                        grid_type = "equal_range",
+                        lambda_seq = exp(seq(-1, -13, length = 300))
                       )) {
   # set defaults and check arguments
   fit_type <- match.arg(fit_type)
@@ -136,7 +134,8 @@ est_g_exp <- function(A,
       stats::predict(
         object = fit_g_exp_dens_hal,
         new_A = as.numeric(data_in$A),
-        new_W = as.matrix(data_in[, colnames(W), with = FALSE])
+        new_W = as.matrix(data_in[, colnames(W), with = FALSE]),
+        trim = FALSE
       )
   } else if (fit_type == "sl" & !is.null(sl_learners_density)) {
     suppressMessages(
@@ -150,7 +149,8 @@ est_g_exp <- function(A,
       stats::predict(
         object = fit_g_exp_dens_hal,
         new_A = as.numeric(data_in_downshifted$A),
-        new_W = as.matrix(data_in[, colnames(W), with = FALSE])
+        new_W = as.matrix(data_in[, colnames(W), with = FALSE]),
+        trim = FALSE
       )
   } else if (fit_type == "sl" & !is.null(sl_learners_density)) {
     suppressMessages(
@@ -164,7 +164,8 @@ est_g_exp <- function(A,
       stats::predict(
         object = fit_g_exp_dens_hal,
         new_A = as.numeric(data_in_upshifted$A),
-        new_W = as.matrix(data_in[, colnames(W), with = FALSE])
+        new_W = as.matrix(data_in[, colnames(W), with = FALSE]),
+        trim = FALSE
       )
   } else if (fit_type == "sl" & !is.null(sl_learners_density)) {
     suppressMessages(
@@ -178,7 +179,8 @@ est_g_exp <- function(A,
       stats::predict(
         object = fit_g_exp_dens_hal,
         new_A = as.numeric(data_in_upupshifted$A),
-        new_W = as.matrix(data_in[, colnames(W), with = FALSE])
+        new_W = as.matrix(data_in[, colnames(W), with = FALSE]),
+        trim = FALSE
       )
   } else if (fit_type == "sl" & !is.null(sl_learners_density)) {
     suppressMessages(
